#
# spec file for package grilo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grilo
Version:        0.3.16
Release:        1.4
Summary:        Framework for browsing and searching media content
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://live.gnome.org/Grilo
Source0:        https://download.gnome.org/sources/grilo/0.3/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  meson >= 0.62.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= 2.58
BuildRequires:  pkgconfig(glib-2.0) >= 2.58
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(oauth)
BuildRequires:  pkgconfig(totem-plparser) >= 3.4.1
BuildRequires:  pkgconfig(vapigen) >= 0.27

%description
Grilo is a framework for browsing and searching media content from
various sources using a single API.

%package -n libgrilo-0_3-0
Summary:        Framework for browsing and searching media content
# Needed for the -lang package to be installable
# Without plugins, grilo is useless
Group:          System/Libraries
Recommends:     grilo-plugins
Provides:       %{name} = %{version}

%description -n libgrilo-0_3-0
Grilo is a framework for browsing and searching media content from
various sources using a single API.

%package -n typelib-1_0-Grl-0_3
Summary:        Framework for browsing and searching media content -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Grl-0_3
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides the GObject Introspection bindings for the
libgrl library.

%package -n libgrlnet-0_3-0
Summary:        Framework for browsing and searching media content -- Networking Helper Library
Group:          System/Libraries

%description -n libgrlnet-0_3-0
Grilo is a framework for browsing and searching media content from
various sources using a single API.

%package -n libgrlpls-0_3-0
Summary:        Framework for browsing and searching media content -- Playlist Helper Library
Group:          System/Libraries

%description -n libgrlpls-0_3-0
Grilo is a framework for browsing and searching media content from
various sources using a single API.

%package -n typelib-1_0-GrlNet-0_3
Summary:        Introspection bindings for grilo
Group:          System/Libraries

%description -n typelib-1_0-GrlNet-0_3
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides the GObject Introspection bindings for the
libgrlnet library.

%package -n typelib-1_0-GrlPls-0_3
Summary:        Introspection bindings for grilo
Group:          System/Libraries

%description -n typelib-1_0-GrlPls-0_3
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides the GObject Introspection bindings for the
libgrlnet library.

%package tools
Summary:        Framework for browsing and searching media content -- Tools
Group:          Productivity/Multimedia/Other

%description tools
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides tools related to Grilo.

%package devel
Summary:        Framework for browsing and searching media content -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libgrilo-0_3-0 = %{version}
Requires:       libgrlnet-0_3-0 = %{version}
Requires:       libgrlpls-0_3-0 = %{version}
Requires:       typelib-1_0-Grl-0_3 = %{version}
Requires:       typelib-1_0-GrlNet-0_3 = %{version}
Requires:       typelib-1_0-GrlPls-0_3 = %{version}

%description devel
Grilo is a framework for browsing and searching media content from
various sources using a single API.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D soup3=true \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
# Create directories needed for plugins
install -d %{buildroot}%{_libdir}/grilo-0.3
install -d %{buildroot}%{_datadir}/grilo-0.3/plugins
%fdupes %{buildroot}%{_datadir}

%check
%meson_test

%ldconfig_scriptlets -n libgrilo-0_3-0
%ldconfig_scriptlets -n libgrlnet-0_3-0
%ldconfig_scriptlets -n libgrlpls-0_3-0

%files -n libgrilo-0_3-0
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/libgrilo-0.3.so.*
# Directories needed for plugins
%dir %{_libdir}/grilo-0.3

%files -n typelib-1_0-Grl-0_3
%{_libdir}/girepository-1.0/Grl-0.3.typelib

%files -n libgrlnet-0_3-0
%license COPYING

%{_libdir}/libgrlnet-0.3.so.*

%files -n libgrlpls-0_3-0
%license COPYING

%{_libdir}/libgrlpls-0.3.so.*

%files -n typelib-1_0-GrlNet-0_3
%{_libdir}/girepository-1.0/GrlNet-0.3.typelib

%files -n typelib-1_0-GrlPls-0_3
%{_libdir}/girepository-1.0/GrlPls-0.3.typelib

%files tools
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/grl-inspect-0.3
%{_bindir}/grl-launch-0.3
%{_bindir}/grilo-test-ui-0.3
%{_mandir}/man1/grilo-test-ui-0.3.1%{?ext_man}
%{_mandir}/man1/grl-inspect-0.3.1%{?ext_man}
%{_mandir}/man1/grl-launch-0.3.1%{?ext_man}

%files devel
%doc %{_datadir}/gtk-doc/html/grilo/
%{_includedir}/grilo-0.3/
%{_libdir}/*.so
%{_libdir}/pkgconfig/grilo-0.3.pc
%{_libdir}/pkgconfig/grilo-net-0.3.pc
%{_libdir}/pkgconfig/grilo-pls-0.3.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/*.deps
%{_datadir}/vala/vapi/*.vapi

%files lang -f %{name}.lang

%changelog
* Tue May  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.16:
  + Fix usage of depcreated GSimpleAsyncResult.
  + Build updates. Meson requirement is now 0.62.
  + Fix build on Darwin.
  + Updated translations.
* Fri Sep 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to soup3 again: Drop pkgconfig(libsoup-2.4) and enable
  pkgconfig(libsoup-3.0) BuildRequires and pass soup3=true to
  meson.
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add back pkgconfig(libsoup-2.4) and disable
  pkgconfig(libsoup-3.0) BuildRequires, and pass soup3=false to
  meson, grilo will not be ready to use new soup3 this cycle.
* Tue Aug 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.15:
  + Increase glib requirement to 2.66 so we can use GUri.
  + net:
  - Add libsoup3 support with compile-time option.
  - Add documentation on throttling property in libsoup3.
  + Build fixes and cleanups.
  + Updated translations.
- Replace pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0)
  BuildRequires, build with soup3 support.
- Stop passing enable-gtk-doc=true to meson, it is the default
  anyway.
- Use ldconfig_scriptlets macro for post(un) handling.
* Wed Oct  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.3.14:
  + CVE-2021-39365: Fix TLS cert validation not being done for any
    network call.
  + Fix double-free when using GrlNet in Python.
  + Load config from GRL_CONFIG_PATH if set.
  + Clarify LGPLv2.1 or later license.
  + Handle numeric limits for GrlOperationOptions.
  + Updated translations.
- Drop grilo-CVE-2021-39365.patch: fixed upstream.
* Fri Aug 27 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add grilo-CVE-2021-39365.patch: Fix missing TLS certificate
  verification(glgo#GNOME#grilo#146 bsc#1189839 CVE-2021-39365).
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 0.3.13:
  + API addition: grl_related_keys_set_for_id().
  + Fix trying to load .so.p files as plugins.
  + Fix crash using get_plugins() from bindings.
  + Several other fixes and cleanups.
  + Updated translations.
* Fri Feb 14 2020 bjorn.lie@gmail.com
- Update to version 0.3.12:
  + grl-source: Fix reference count in the bindings.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Jan  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.11:
  + pls: Support totem-pl-parser 3.26.4.
  + build:
  - Add a Meson dependency variable for libgrlpls.
  - Avoid using meson.source_root().
- Drop grilo-fix-build-totem-pl-parser.patch: Fixed upstream.
* Tue Nov 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add grilo-fix-build-totem-pl-parser.patch: Fix build with
  totem-pl-parser 3.26.4.
* Sat Sep 14 2019 bjorn.lie@gmail.com
- Update to version 0.3.10:
  + build: Use variables in pc files.
  + Fix grl_data_add_related_keys annotation.
  + Use only one primary header for style.
- Add optional pkgconfig(oauth) BuildRequires: Build oauth support.
- Enable check section and run meson_test.
* Wed Jul 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.9:
  + grl-metadata-key: fix introspection.
  + grl-inspect: Fix core keys extraction.
* Tue Jul 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.8:
  + Add missing symbols to the docs.
  + pls: Simplify thumbnail validity handling.
  + media: Fix get_last_played annotation.
  + Add metadata keys for MB Release ID and MB Release Group ID.
  + Deprecates GRL_METADATA_KEY_MB_RELEASE_ID and
    GRL_METADATA_KEY_MB_RELEASE_GROUP_ID.
  + Removes obsolte GRL_CAPS_TYPE and GRL_OPERATION_OPTIONS_TYPE.
  + Updated translations.
* Wed Nov 21 2018 bjorn.lie@gmail.com
- Update to version 0.3.7:
  + Fix crash in totem after emitting source-{add remove}.
  +  Add grl_related_keys_{get,set}_int64 functions.
  + Support transform GValue on grl_data_*_for_id().
  + Add per Source configs on keyfile.
  + Pattern matching for GRL_PLUGIN_RANKS.
  + Documentation improvements.
  + Removed Autotools supported.
  + Updated translations.
- Add meson BuildRequires and macros, switch to meson buildsystem
  following upstreams changes.
* Fri Jul 27 2018 bjorn.lie@gmail.com
- Update to version 0.3.6:
  + Last release with Autotools included.
  + Add support to build of grl-inspect with Python3.
  + Bugs fixed: glgo#GNOME/grilo!1
  + Updated translations.
* Tue Jul 17 2018 bjorn.lie@gmail.com
- Update to version 0.3.5:
  + Bugs fixed: glgo#GNOME/grilo!10, glgo#GNOME/grilo!9,
    glgo#GNOME/grilo#4, glgo#GNOME/grilo#2.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Aug 24 2017 zaitor@opensuse.org
- Update to version 0.3.4:
  + Bugs fixed: bgo#707643, bgo#778612.
  + Updated translations.
* Tue Feb 14 2017 zaitor@opensuse.org
- Update to version 0.3.3:
  + Support for Meson build included.
  + Updated Travis CI to use docker and support meson builds.
  + Bugs fixed: bgo#771339, bgo#773422, bgo#774394, bgo#774578,
    bgo#775950.
  + Updated translations.
- Drop grilo-fix-32bit-build.patch: Fixed upstream.
* Sat Sep 10 2016 dimstar@opensuse.org
- Add grilo-fix-32bit-build.patch: Fix build on i586 (bgo#769331).
* Sat Sep 10 2016 dimstar@opensuse.org
- Pass --disable-debug to configure: make use of fortified sources
  as passed in our optflags (-D_FORTIFY_SOURCE=2).
* Sat Sep 10 2016 zaitor@opensuse.org
- Update to version 0.3.2:
  + Bugs fixed: bgo#766386, bgo#769331, bgo#769830.
  + Updated translations.
* Fri Jun 17 2016 zaitor@opensuse.org
- Update to version 0.3.1:
  + Added new keys: GRL_METADATA_KEY_ALBUM_DISC_NUMBER,
    GRL_METADATA_KEY_COMPOSER, GRL_METADATA_KEY_ALBUM_ARTIST.
  + Deprecated GRL_NET errors in favour of GRL_IO errors.
  + Bugs fixed: bgo#732879, bgo##760426, bgo#760648, bgo#761820,
    bgo#761868, bgo#763009, bgo#764077.
  + Updated translations.
* Mon Dec 21 2015 damjanovic.ivo@gmail.com
- Update to version 0.3.0:
  + "last-played-time" now is a GDateTime key, instead of string.
  + Support builtin plugins.
  + Get rid of XML plugin definitions.
  + New way of defining plugins (GRL_PLUGIN_DEFINE).
  + Plugins must be explicitly activated after loading them.
  + Merge GrlMedia{Audio,Video,Image,Box} in GrlMedia.
  + Updated translations.
- Rename libgrilo-0_2-1 to libgrilo-0_3-0, typelib-1_0-Grl-0_2 to
  typelib-1_0-Grl-0_3, libgrlnet-0_2-0 to libgrlnet-0_3-0,
  libgrlpls-0_2 to libgrlpls-0_3, typelib-1_0-GrlNet-0_2 to
  typelib-1_0-GrlNet-0_3, typelib-1_0-GrlPls-0_2 to
  typelib-1_0-GrlPls-0_3 following upstreams soname bumps.
* Sat Dec 19 2015 zaitor@opensuse.org
- Update to version 0.2.15:
  + Support builtin plugins.
  + Bugs fixed: bgo#747026, bgo#755368, bgo#755433, bgo#755516,
    bgo#755702, bgo#758654, bgo#758655.
  + Updated translations.
* Wed Sep  9 2015 dimstar@opensuse.org
- Update to version 0.2.14:
  + Fix soname bump version.
- Changes from version 0.2.13:
  + Updated i18n
  + Fixed tests
  + Added GRL_CORE_ERROR_AUTHENTICATION_TOKEN
  + Bugs fixed: bgo#745676, bgo#747029, bgo#747953, bgo#748455,
    bgo#748550, bgo#748873, bgo#748896, bgo#749587, bgo#749887,
    bgo#754093, bgo#754401.
  + Updated translations.
- Disable make check: as we installed to %%{buildroot}, the plugins
  cannot be found in the location configured (outside of
  %%{buildroot}).
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 0.2.12:
  + Add man pages for grilo-test-ui and grl-launch.
  + Modernized Vala bindings.
  + Sources are network aware.
  + Internal changes.
  + Several fixes, including: bgo#724308, bgo#725148, bgo#730663,
    bgo#732878, bgo#740113, bgo#740128, bgo#740186, bgo#740761,
    bgo#740942, bgo#740943, bgo#741020, bgo#741081, bgo#741207,
    bgo#741230, bgo#741315, bgo#741605, bgo#742645, bgo#743351,
    bgo#743353, bgo#744168, bgo#744408.
  + Updated translations.
* Sun Aug 24 2014 zaitor@opensuse.org
- Update to version 0.2.11:
  + Fixes in build system.
  + Generate AUTHORS file automatically-
  + Added new keys: GRL_METADATA_KEY_TITLE_FROM_FILENAME,
    GRL_METADATA_KEY_MB_ALBUM_ID.
  + Added new tool: grl-launch, to run Grilo operations from
    command line.
  + Bugs fixed: bgo#706877, bgo#726698, bgo#727223, bgo#728812,
    bgo#730003, bgo#730548, bgo#731282, bgo#733232, bgo#733285.
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 0.2.10:
  + Increase glib requirement to 2.34 or greater.
  + Added new property in GrlSource: "source-tags".
  + Added new signal in GrlRegistry: "metadata-key-added".
  + Added new functions: grl_media_{set,get}_size().
  + Added new key: GRL_METADATA_KEY_SIZE.
  + Updated man page.
  + Bugs fixed: bgo#629002, bgo#724019, bgo#724648, bgo#724658,
    bgo#724660, bgo#724871, bgo#725419, bgo#726197, bgo#726340.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 0.2.9:
  + Several fixes, including:
  - Fix introspection scanner warnings (bgo#724620).
  - Return an error when the entry media is of the wrong type
    (bgo#724540).
  - Remove check for libvala in configure.ac (bgo#724430).
- Replace pkgconfig(libvala-0.24) for pkgconfig(vapigen) since
  configure does not look for a particular version anymore.
* Tue Feb 11 2014 dimstar@opensuse.org
- Update to version 0.2.8:
  + Added support for Vala 0.22 and 0.24.
  + Bump required libglib version to 2.32.
  + Added new core function: grl_deinit().
  + Added new property in GrlSource: "source-icon".
  + Added a new library: Grilo Playlist, to handle playlists as
    containers.
  + Bugs fixed: bgo#657926, bgo#695303, bgo#709208, bgo#709651,
    bgo#710185, bgo#722358, bgo#722398, bgo#722407, bgo#723077,
    bgo#723191, bgo#723989, bgo#724018.
  + Updated translations.
- Pass --enable-grl-pls to configure to ensure playlist support is
  being enabled.
- Add pkgconfig(totem-plparser) BuildRequires: dependency for the
  playlist support.
- Drop grilo-libvala-0.22.patch and grilo-libvala-0.24.patch: fixed
  upstream.
- Drop gnome-common BuildRequires and call to gnome-autgen.sh: no
  longer required, as we don't carry any patches.
- Add libgrlpls-0_2-0 and typelib-1_0-GrlNet-0_2 subpackages: new
  libraries.
- Require libgrlpls-0_2-0 and typelib-1_0-GrlNet-0_2 by the
  - devel package.
* Tue Jan 28 2014 dimstar@opensuse.org
- Switch to vala 0.24 for GNOME 3.12 target:
  + Replace pkgconfig(libvala-0.22) BuildRequires with
    pkgconfig(libvala-0.24), for the actual switch.
  + Add grilo-libvala-0.24.patch: Add support for Vala 0.24.
* Wed Sep 18 2013 dimstar@opensuse.org
- Update to version 0.2.7:
  + Added Travis CI support for building.
  + Bump required libsoup version to 2.4.
  + Re-factored Grilo Net library and fixed several bugs.
  + Show 'slow' keys in grl-inspect.
  + Updates in documentation.
  + dded new core function: grl_operation_set_data_full().
  + Bugs fixed: bgo#700478, bgo#704804, bgo#705944, bgo#706132,
    bgo#706412, bgo#706487, bgo#706491, bgo#706495, bgo#706805,
    lp#1224410.
  + Updated translations.
* Sun Aug 18 2013 zaitor@opensuse.org
- Add grilo-libvala-0.22.patch: Add libvala 0.22 support.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
- Exchange pkgconfig(libvala-0.20) for pkgconfig(libvala-0.22)
  BuildRequires.
* Fri May 17 2013 dimstar@opensuse.org
- Update to version 0.2.6:
  + Fixed GrlNet cache.
  + Added support for Vala 0.20.
  + Improved test-ui.
  + Some fixes, including bgo#696860, bgo#697175, bgo#700310,
    bgo#700311.
  + Added new functions in GrlConfig
  - grl_config_get_api_token_secret().
  - grl_config_set_api_token_secret().
  + Improved grl-inspect
  - Print list of available keys.
  - Show more information about plugins.
  + Updated translations.
- Drop grilo-libvala-0.20.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh, as
  we no longer carry any patches.
- Create a -lang package.
- Provide %%{name} by libgrilo package, in order to have the -lang
  package installable.
- Recommend grilo-lang from libgrilo.
* Thu Apr 18 2013 dimstar@opensuse.org
- Add grilo-libvala-0.20.patch: Add libvala 0.20 support.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 0.2.5:
  + Fixed compilation problem with gcc 4.2.
  + Removed some warnings.
  + Several changes in test-ui
  + Bugs fixed: bgo#689577, bgo#690612, bgo#690613, bgo#692118,
    bgo#692873, bgo#694390.
* Sun Dec  2 2012 dimstar@opensuse.org
- Update to version 0.2.4:
  + Fixed compilation problem with gcc 4.2.
  + Improved documentation.
  + Added support for boolean, float and datetime keys in filters.
  + Some fixes in core, including:
  - bgo#688301: docs: GrlMedia: Improve certificate/region
    function docs.
  - bgo#689053: grl-source: fix compare_queue_element function.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 0.2.3:
  + Added TMDb plugin in the Test UI program.
  + grl_source_resolve() can be invoked with sources that do not
    implement it
  + grl_source_store_metadata() can be invoked with sources that do
    not implement it
  + Added support for mocking network answers, for testing purpose
  + Added support for capturing network content, for testing
    purpose
  + Improved (de)serialization: support all metadata key types and
    multi-valued elements
  + Added new keys: GRL_METADATA_KEY_FAVOURITE,
    GRL_METADATA_KEY_REGION, GRL_METADATA_KEY_KEYWORD,
    GRL_METADATA_KEY_PERFORMER, GRL_METADATA_KEY_PRODUCER,
    GRL_METADATA_KEY_DIRECTOR and GRL_METADATA_KEY_ORIGINAL_TITLE
  + Sources can expose the type of media they can handle
  + Improved documentation
  + Bugs fixed: bgo#679686, bgo#685274, bgo#685861, bgo#685967,
    bgo#686032, bgo#686033, bgo#686206, bgo#686271, bgo#687104.
- Drop grilo-linking.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh, as
  we no longer carry any patches.
* Wed Oct 17 2012 dimstar@opensuse.org
- Add grilo-linking.patch: Fix linking of GrlNet.gir.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the BuildSystem.
* Fri Oct  5 2012 dimstar@opensuse.org
- Update to version 0.2.2:
  + Rename macro from GRL_CAPS_TYPE to GRL_TYPE_CAPS
  + Sort entries in documentation
  + net: Add possibility to set custom HTTP headers on requests
    (bgo#680436)
  + Several bug fixes.
* Thu Oct  4 2012 dimstar@opensuse.org
- Update to version 0.2.1:
  + Use G_MODULE_BIND_LOCAL to load modules
  + Less disturbances using warnings instead of errors
  + Add option to disable Test UI
  + Bugs fixed: bgo#681757, bgo#681983, bgo#681984, bgo#681992,
    bgo#682024, bgo#682791, bgo#682793, bgo#682855, bgo#685161,
    bgo#685169.
- Drop grilo-int2pointer.patch: fixed upstream.
- Replace pkgconfig(libvala-0.16) BuildRequires with
  pkgconfig(libvala-0.18): As this package lives in the same
  devel project as vala, we don't have to care too much about older
  versions to be found in older openSUSE releases.
- Pass --enable-vala to configure: this helps us to abort the build
  early in case something does not work out as expected rather than
  only at the end, when the files section does not match.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 0.2.0:
  + Merged GrlMediaSource and GrlMetadataSource in one GrlSource
  + Improvements in the full resolution algorithm
  + Added operation options and source capabilities
  + Added filtering capabilities
  + Changes in API names
  + Added support for Vala 0.14 - 0.18
  + Added support for Windows building
  + Use GDateTime for date-based keys
  + Use numbers to identify metadata keys
  + Improvements in Grilo Net library
  + Improvements in Vala bindings
  + Improvements in documentation
  + Improvements in the build system
  + Bugs fixed: bgo#662748, bgo#662762, bgo#662763, bgo#665938.
- Add grilo-int2pointer.patch: Fix brp errors, taken from git.
- Rename libgrilo-0_1-0 to libgrilo-0_2-1, typelib-1_0-Grl-0_1 to
  typelib-1_0-Grl-0_2, libgrlnet-0_1-0 to libgrlnet-0_2-0,
  typelib-1_0-GrlNet-0_1 to typelib-1_0-GrlNet-0_2, following
  upstreams soname bumps.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 0.1.20:
  + Test UI requires Gtk+ 3
  + Fixes in the Test UI
  + Improved documentation
  + Bugs fixed: bgo#676822, bgo#676823, bgo#679674.
* Wed Jun  6 2012 dimstar@opensuse.org
- Update to version 0.1.19:
  + Fixes in the Test UI
  + Improvements in Grilo Net library
  + Added support for Vala 0.16 and 0.18
  + Improvements in the build system
  + Several fixes, including:
  - bgo#662748: tracker plugin: support multiple resources in a
    larger file
  - bgo#665938: Do not dist gir_DATA
  - bgo#672923: Make it possible to override the user-agent in
    GrlNetWc
- Drop grilo-vala-0_16.patch: fixed upstream
- Drop gnome-commong BuildRequires and call to gnome-autogen.sh:
  no longer needed, as we don't carry any patches anymore.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Fri Jan 13 2012 dimstar@opensuse.org
- Change pkgconfig(libvala-0.14) BuildRequires to
  pkgconfig(libvala-0.16)
- Add grilo-vala-0_16.patch: Detect libvala 0.16
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
* Sat Dec 10 2011 dimstar@opensuse.org
- Update to version 0.1.18:
  + Added support for Windows builds
  + Bugs fixed: bgo#662762, bgo#662763.
- Drop grilo-no-wc-test.patch: fixed upstream
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as we do no longer carry any patches.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib files into their own subpackages:
  typelib-1_0-Grl-0_1 and typelib-1_0-GrlNet-0_1.
- Add typelib-1_0-Grl-0_1 and typelib-1_0-GrlNet-0_1 Requires to
  devel subpackage.
* Sun Nov 27 2011 dimstar@opensuse.org
- Add grilo-no-wc-test.patch: wc-test fails to build with new glib.
  Instead of fixing the build, we follow upstreams approch and drop
  it.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  the patch modifies the build system.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 0.1.17:
  + Minor improvements in documentation
  + Well-manage end of search/browse in splitted sources
  + Minor fixes in build system
  + Install XML files in the same place as libraries
  + Restrict loading of a subset of plugins
  + Added support for Vala 0.14
  + Fixed some bugs, including: bgo#657549, bgo#657920.
- Remove sed hack in %%build to support vala 0.14: fixed upstream.
* Wed Aug  3 2011 dimstar@opensuse.org
- Spec cleanup for inclusion into Factory.
* Thu Jul  7 2011 cbosdonnat@novell.com
- Added vala and gtk+3 dependencies
- Spec file cleanup
* Thu Jul  7 2011 cbosdonnat@novell.com
- Created initial packages with grilo 0.1.16
